// Class QCaptionButton 
// Button with Caption
// Filename QCaptionButton.cpp
// FaPra 2003-2004, A5,  Alexander Kramer


#include "QCaptionButton.h"
#include <iostream>
using namespace std;

// ----------------------------------------------------------

//! overwrite this to recalculate caption position
void QCaptionButton::updateCaptionPosition()
{
 int TextWidth = (int)(Font->getTextWidth(Caption.c_str()));
  if (Width < (TextWidth+10))
   Width = TextWidth+10;
 CaptionPositionX = (Width-TextWidth)/2;
} // end of updateCaptionPosition()

//! draws itself with OpenGL. Here is the OpenGL drawing code
void QCaptionButton::draw( QEvent*  e )
{

  LookAndFeel->getBackGroundColor()->setAsCurrent();
  glBegin(GL_POLYGON);
  LookAndFeel->drawRect(0,0,Width,Height);
  glEnd();

  LookAndFeel->drawBevel(0,0,Width,Height,State);

  if (getFocused())
  {
    LookAndFeel->getHighlightColor()->setAsCurrent();
    glBegin(GL_LINE_LOOP);
    LookAndFeel->drawRect(1,1,Width-2,Height-2);
    glEnd();
  }

  // drawing all other stuff translated
  if (State == bsDown)
   glTranslatef(1,1,0);


  Font->drawAtPos(Caption.c_str(),CaptionPositionX,1,Font->getLengthForWidth(Caption.c_str(),Width));
} // end of draw()

//! layout the children widgets. This method is called every time the size is changed. Have to be overwritten for respond on size changes
void QCaptionButton::layout()
{
 QButton::layout();
 updateCaptionPosition();
} // end of layout()

//! have to return true if widget should be dragged with mouse. This method is overwritten in sub classes. If returns true, widget will be dragged
bool QCaptionButton::canDrag( QEvent*  e )
{
 return false;
} // end of canDrag()

//! processing mouse/keyboard events which are in widgets region. Mouse coordinates are relative to Owner
bool QCaptionButton::processEvent( QEvent*  e )
{
 return QButton::processEvent(e);
} // end of processEvent()

//! processing mouse events which are in Owner widget region. Mouse coordinates are relative to Owner
bool QCaptionButton::processMouseOwner( QEvent*  e )
{
 return QButton::processMouseOwner(e);
} // end of processMouseOwner()

//! called if a child is added/removed
void QCaptionButton::childrenChanged()
{
} // end of childrenChanged()

//! defines whether control can have keyboard focus. Should return true if Widget wants to get keyboard focus
bool QCaptionButton::canFocus( QEvent*  e )
{
 return true;
} // end of canFocus()

//! initialization code
void QCaptionButton::Init()
{
  QButton::Init();
  Font->copyFrom(LookAndFeel->getFont());
  Height = 20;
  setCaption("Button");
} // end of Init()

//! clean up code
void QCaptionButton::CleanUp()
{
  QButton::CleanUp();
} // end of CleanUp()

//! getter method for Caption
string QCaptionButton::getCaption()
{
return Caption;
} // end of getCaption()

//! setter method for Caption
void QCaptionButton::setCaption( string  newValue )
{
 Caption = newValue;
 updateCaptionPosition();
} // end of setCaption()

//! getter method for Font
QFont* QCaptionButton::getFont()
{
return Font;
} // end of getFont()

// WARNING : The implementation of this method will be automatically generated with code generator.
// To prevent this add '//KEEP' at the first line of the implementation.(first line after '{')
//! prints itself to the cout
void QCaptionButton::print()
{
cout << "Class : QCaptionButton" << endl;
cout << "Caption = " << Caption << endl;
} // end of print()

// WARNING : The implementation of this method will be automatically generated with code generator.
// To prevent this add '//KEEP' at the first line of the implementation.(first line after '{')
//! Constructor
 QCaptionButton::QCaptionButton( QWidget*  aOwner ):QButton(aOwner)
{
Font = new QFont;
Init();
layout();
} // end of QCaptionButton()

// WARNING : The implementation of this method will be automatically generated with code generator.
// To prevent this add '//KEEP' at the first line of the implementation.(first line after '{')
//! Destructor
 QCaptionButton::~QCaptionButton()
{
delete Font;
CleanUp();
} // end of ~QCaptionButton()

// end of implementation of QCaptionButton


