// Class QLookAndFeel 
// Filename QLookAndFeel.h 
// FaPra 2003-2004, A5, Alexander Kramer

#ifndef QLookAndFeel_h 
#define QLookAndFeel_h 


//! Pre-declaration of QLookAndFeel
class QLookAndFeel;


//! enumeration of bevel states
enum QBevelState {bsUp, bsDown, bsDisabled };

#include "QColor.h"
#include "QFont.h"

//! Defines Look and Feel. Colors, Textures, default Font size and so on.
class QLookAndFeel
{
private:
//! id for checkbox texture
unsigned int CheckBoxTexID;

//! id for checkbox texture
unsigned int CheckBoxCheckedTexID;

//! id for radio button checked texture
unsigned int RadioButtonCheckedTexID;

//! id for radio button texture
unsigned int RadioButtonTexID;

//! id for close button texture
unsigned int CloseButtonTexID;

//! id for close button down texture
unsigned int CloseButtonDownTexID;

//! id for maximize button texture
unsigned int MaximizeButtonTexID;

//! id for maximize button down texture
unsigned int MaximizeButtonDownTexID;

//! id for restore button texture
unsigned int RestoreButtonTexID;

//! id for restore button down texture
unsigned int RestoreButtonDownTexID;

//! id for miniimize button texture
unsigned int MinimizeButtonTexID;

//! id for minimize button down texture
unsigned int MinimizeButtonDownTexID;

protected:
//! back ground color
QColor* BackGroundColor;

//! color of control if it is disabled
QColor* DisabledColor;

//! color of the raised side of a bevel
QColor* BevelRaisedColor;

//! color of the lowered side of a bevel
QColor* BevelLoweredColor;

//! color of the side of a disabled bevel
QColor* BevelDisabledColor;

//! highlighted color
QColor* HighlightColor;

//! reference font
QFont* Font;

public:
//! draws bevel from x,y-x+w,y+h. State : up,down,disabled
 void drawBevel( float  x , float  y , float  w , float  h , QBevelState  state );

//! draws bevel from x,y-x+w,y+h. State : up,down,disabled
 void drawRect( float  x , float  y , float  w , float  h );

//! draws given texture with given size
 void drawTexture( unsigned  int  texID , int  width , int  height );

//! draws checkbox texture
 void drawCheckBox( bool  checked );

//! draws radio button texture
 void drawRadioButton( bool  checked );

//! draws close button texture
 void drawCloseButton( bool  down , int  width , int  height );

//! draws maximize button texture
 void drawMaximizeButton( bool  down , int  width , int  height );

//! initialization code
virtual void Init();

//! clean up code
virtual void CleanUp();

//! getter method for BackGroundColor
 QColor* getBackGroundColor();

//! getter method for DisabledColor
 QColor* getDisabledColor();

//! getter method for BevelRaisedColor
 QColor* getBevelRaisedColor();

//! getter method for BevelLoweredColor
 QColor* getBevelLoweredColor();

//! getter method for BevelDisabledColor
 QColor* getBevelDisabledColor();

//! getter method for HighlightColor
 QColor* getHighlightColor();

//! getter method for Font
 QFont* getFont();

//! prints itself to the cout
 void print();

//! Constructor
  QLookAndFeel(  );

//! Destructor
virtual  ~QLookAndFeel();


};
#endif

