// Class QRadioButton 
// Radio Button
// Filename QRadioButton.cpp
// FaPra 2003-2004, A5,  Alexander Kramer


#include "QRadioButton.h"
#include <iostream>
using namespace std;

// ----------------------------------------------------------

//! draws itself with OpenGL. Here is the OpenGL drawing code
void QRadioButton::draw( QEvent*  e )
{
 LookAndFeel->drawRadioButton(State == cbChecked);
 glTranslatef(BoxSize+2,(BoxSize-Font->getSize())/2,0);
 Font->drawInternal(Caption.c_str(),-1);
} // end of draw()

//! layout the children widgets. This method is called every time the size is changed. Have to be overwritten for respond on size changes
void QRadioButton::layout()
{
  QCheckBox::layout();
} // end of layout()

//! have to return true if widget should be dragged with mouse. This method is overwritten in sub classes. If returns true, widget will be dragged
bool QRadioButton::canDrag( QEvent*  e )
{
 return false;
} // end of canDrag()

//! processing mouse/keyboard events which are in widgets region. Mouse coordinates are relative to Owner
bool QRadioButton::processEvent( QEvent*  e )
{
 if (e->getType() == etMouseDown)
 {
   if (RadioButtonGroup != 0)
   {
     RadioButtonGroup->setAsSelected(this);
   }
   else
   {
     QCheckBox::processEvent(e);
   }
   return true;
 }
 return false;
} // end of processEvent()

//! processing mouse events which are in Owner widget region. Mouse coordinates are relative to Owner
bool QRadioButton::processMouseOwner( QEvent*  e )
{
 return false;
} // end of processMouseOwner()

//! called if a child is added/removed
void QRadioButton::childrenChanged()
{
} // end of childrenChanged()

//! defines whether control can have keyboard focus. Should return true if Widget wants to get keyboard focus
bool QRadioButton::canFocus( QEvent*  e )
{
 return true;
} // end of canFocus()

//! initialization code
void QRadioButton::Init()
{
  QCheckBox::Init();
} // end of Init()

//! clean up code
void QRadioButton::CleanUp()
{
} // end of CleanUp()

//! getter method for RadioButtonGroup
QRadioButtonGroup* QRadioButton::getRadioButtonGroup()
{
return RadioButtonGroup;
} // end of getRadioButtonGroup()

//! setter method for RadioButtonGroup
void QRadioButton::setRadioButtonGroup( QRadioButtonGroup*  newValue )
{
  if (RadioButtonGroup != newValue)
  {
    if (RadioButtonGroup != 0)
    {
      RadioButtonGroup->remove(this);
    }

    RadioButtonGroup = newValue;

    if (RadioButtonGroup != 0)
    {
      RadioButtonGroup->add(this);
    }
  }
} // end of setRadioButtonGroup()

// WARNING : The implementation of this method will be automatically generated with code generator.
// To prevent this add '//KEEP' at the first line of the implementation.(first line after '{')
//! prints itself to the cout
void QRadioButton::print()
{
cout << "Class : QRadioButton" << endl;
cout << "RadioButtonGroup = " << RadioButtonGroup << endl;
} // end of print()

// WARNING : The implementation of this method will be automatically generated with code generator.
// To prevent this add '//KEEP' at the first line of the implementation.(first line after '{')
//! Constructor
 QRadioButton::QRadioButton( QWidget*  aOwner ):QCheckBox(aOwner)
{
RadioButtonGroup = 0;
Init();
layout();
} // end of QRadioButton()

// WARNING : The implementation of this method will be automatically generated with code generator.
// To prevent this add '//KEEP' at the first line of the implementation.(first line after '{')
//! Destructor
 QRadioButton::~QRadioButton()
{
CleanUp();
} // end of ~QRadioButton()

// end of implementation of QRadioButton


