// Class QTextEdit 
// Text edit widget
// Filename QTextEdit.cpp
// FaPra 2003-2004, A5,  Alexander Kramer


#include "QTextEdit.h"
#include <iostream>
using namespace std;

// ----------------------------------------------------------

//! draws itself with OpenGL. Here is the OpenGL drawing code
void QTextEdit::draw( QEvent*  e )
{
  if (Enabled)
  {
    if (Owner->getFocusPath() == this)
    {
      LookAndFeel->getHighlightColor()->setAsCurrent();
    }
    else
    {
      LookAndFeel->getBackGroundColor()->setAsCurrent();
    }
    glBegin(GL_POLYGON);
    LookAndFeel->drawRect(0,0,Width,Height);
    glEnd();
    LookAndFeel->drawBevel(0,0,Width,Height,bsDown);
  }
  else
  {
    LookAndFeel->getBackGroundColor()->setAsCurrent();
    glBegin(GL_POLYGON);
    LookAndFeel->drawRect(0,0,Width,Height);
    glEnd();
    LookAndFeel->drawBevel(0,0,Width,Height,bsDisabled);
  }

  glTranslatef(1,1,0);
  Font->drawInternal(Text.c_str(),-1);

  // draw cursor, the current position is almost right,
  // because the drawInternal has adjusted MV matrix

  if (getFocused())
  {
     glColor3f(0.0,0.0,0.0);
     glLineWidth(2);
     glBegin(GL_LINES);
     glVertex2i(2,1);
     glVertex2i(2,Height-2);
     glEnd();
     glLineWidth(1);
  }
} // end of draw()

//! layout the children widgets. This method is called every time the size is changed. Have to be overwritten for respond on size changes
void QTextEdit::layout()
{
} // end of layout()

//! have to return true if widget should be dragged with mouse. This method is overwritten in sub classes. If returns true, widget will be dragged
bool QTextEdit::canDrag( QEvent*  e )
{
 return false;
} // end of canDrag()

//! processing mouse/keyboard events which are in widgets region. Mouse coordinates are relative to Owner
bool QTextEdit::processEvent( QEvent*  e )
{

  if ((e->getType() == etKeyboard))
  {
     e->print();
     char key = (char)e->getKey();

     if ((key == 8) && (Text.length()>0))
     {
       Text = Text.substr(0,Text.length()-1);
     }
     else if (key >= 32)
     {
      string newText = Text + key;
      setText(newText);
     }
  }

 return false;
} // end of processEvent()

//! processing mouse events which are in Owner widget region. Mouse coordinates are relative to Owner
bool QTextEdit::processMouseOwner( QEvent*  e )
{
 return false;
} // end of processMouseOwner()

//! called if a child is added/removed
void QTextEdit::childrenChanged()
{
} // end of childrenChanged()

//! defines whether control can have keyboard focus. Should return true if Widget wants to get keyboard focus
bool QTextEdit::canFocus( QEvent*  e )
{
 return true;
} // end of canFocus()

//! initialization code
void QTextEdit::Init()
{
  Font->copyFrom(LookAndFeel->getFont());
  Width = 100;
  Height = 20;
} // end of Init()

//! clean up code
void QTextEdit::CleanUp()
{
} // end of CleanUp()

//! getter method for CursorPos
int QTextEdit::getCursorPos()
{
return CursorPos;
} // end of getCursorPos()

//! setter method for CursorPos
void QTextEdit::setCursorPos( int  newValue )
{
CursorPos = newValue;
} // end of setCursorPos()

//! getter method for Text
string QTextEdit::getText()
{
return Text;
} // end of getText()

//! setter method for Text
void QTextEdit::setText( string  newValue )
{
  if (Font->getTextWidth(newValue.c_str())+6 < Width)
  {
     Text = newValue;
  }
} // end of setText()

//! getter method for Font
QFont* QTextEdit::getFont()
{
return Font;
} // end of getFont()

// WARNING : The implementation of this method will be automatically generated with code generator.
// To prevent this add '//KEEP' at the first line of the implementation.(first line after '{')
//! prints itself to the cout
void QTextEdit::print()
{
cout << "Class : QTextEdit" << endl;
cout << "CursorPos = " << CursorPos << endl;
cout << "Text = " << Text << endl;
} // end of print()

// WARNING : The implementation of this method will be automatically generated with code generator.
// To prevent this add '//KEEP' at the first line of the implementation.(first line after '{')
//! Constructor
 QTextEdit::QTextEdit( QWidget*  aOwner ):QWidget(aOwner)
{
CursorPos = 0;
Font = new QFont;
Init();
layout();
} // end of QTextEdit()

// WARNING : The implementation of this method will be automatically generated with code generator.
// To prevent this add '//KEEP' at the first line of the implementation.(first line after '{')
//! Destructor
 QTextEdit::~QTextEdit()
{
delete Font;
CleanUp();
} // end of ~QTextEdit()

// end of implementation of QTextEdit


