// Class QToolBar 
// Filename QToolBar.h 
// FaPra 2003-2004, A5, Alexander Kramer

#ifndef QToolBar_h 
#define QToolBar_h 


//! Pre-declaration of QToolBar
class QToolBar;


#include "QWidget.h"

//! Tool bar which is movable and layouts its widgets horizontal
class QToolBar : public QWidget
{
protected:
//! Width of the left area, which is used to move the Toolbar
int MoverWidth;

public:
//! brings the given widget to the front. Must be a child widget
virtual void bringToFront( QWidget*  widget );

//! draws itself with OpenGL. Here is the OpenGL drawing code
virtual void draw( QEvent*  e );

//! layout the children widgets. This method is called every time the size is changed. Have to be overwritten for respond on size changes
virtual void layout();

//! have to return true if widget should be dragged with mouse. This method is overwritten in sub classes. If returns true, widget will be dragged
virtual bool canDrag( QEvent*  e );

//! processing mouse/keyboard events which are in widgets region. Mouse coordinates are relative to Owner
virtual bool processEvent( QEvent*  e );

//! processing mouse events which are in Owner widget region. Mouse coordinates are relative to Owner
virtual bool processMouseOwner( QEvent*  e );

//! called if a child is added/removed
virtual void childrenChanged();

//! defines whether control can have keyboard focus. Should return true if Widget wants to get keyboard focus
virtual bool canFocus( QEvent*  e );

//! initialization code
virtual void Init();

//! clean up code
virtual void CleanUp();

//! getter method for MoverWidth
virtual int getMoverWidth();

//! setter method for MoverWidth
virtual void setMoverWidth( int  newValue );

//! prints itself to the cout
 void print();

//! Constructor
  QToolBar( QWidget*  aOwner );

//! Destructor
virtual  ~QToolBar();


};
#endif

